X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/ab7ce33c563651f790f99d64ee56727706047ae3..be33a1c72620aad7a221896b24b7f75fe79dbdc5:/include/wx/xrc/xh_sttxt.h

diff --git a/include/wx/xrc/xh_sttxt.h b/include/wx/xrc/xh_sttxt.h
index e6c88984fa..87d0d49a41 100644
--- a/include/wx/xrc/xh_sttxt.h
+++ b/include/wx/xrc/xh_sttxt.h
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        xh_sttxt.h
 // Purpose:     XML resource handler for wxStaticBitmap
 // Author:      Bob Mitchell
 // Created:     2000/03/21
 // RCS-ID:      $Id$
@@ -11,20 +11,20 @@
 #ifndef _WX_XH_STTXT_H_
 #define _WX_XH_STTXT_H_
 
-#if defined(__GNUG__) && !defined(__APPLE__)
-#pragma interface "xh_sttxt.h"
-#endif
-
 #include "wx/xrc/xmlres.h"
 
+#if wxUSE_XRC && wxUSE_STATTEXT
 
-class WXXMLDLLEXPORT wxStaticTextXmlHandler : public wxXmlResourceHandler
+class WXDLLIMPEXP_XRC wxStaticTextXmlHandler : public wxXmlResourceHandler
 {
+    DECLARE_DYNAMIC_CLASS(wxStaticTextXmlHandler)
+
 public:
     wxStaticTextXmlHandler();
     virtual wxObject *DoCreateResource();
     virtual bool CanHandle(wxXmlNode *node);
 };
 
+#endif // wxUSE_XRC && wxUSE_STATTEXT
 
-#endif // _WX_XH_STBMP_H_
+#endif // _WX_XH_STTXT_H_
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
-// Name:        xh_sttxt.h
-// Purpose:     XML resource handler for wxStaticBitmap
+// Name:        wx/xrc/xh_sttxt.h
+// Purpose:     XML resource handler for wxStaticText
 // Author:      Bob Mitchell
 // Created:     2000/03/21